<?php
/**
 * @copyright	Copyright (C) 2011 Simplify Your Web, Inc. All rights reserved.
 * @license		GNU General Public License version 3 or later; see LICENSE.txt
 */

// no direct access
defined('_JEXEC') or die;

/**
 * This is a file to add template specific chrome to module rendering.  To use it you would
 * set the style attribute for the given module(s) include in your template to use the style
 * for each given modChrome function.
 *
 * eg.  To render a module mod_test in the sliders style, you would use the following include:
 * <jdoc:include type="module" name="test" style="slider" />
 *
 * This gives template designers ultimate control over how modules are rendered.
 *
 * NOTICE: All chrome wrapping methods should be named: modChrome_{STYLE} and take the same
 * two arguments.
 *
 * This module chrome file creates custom output for modules used with the Atomic template.
 * The first function wraps modules using the "container" style in a DIV. The second function
 * uses the "bottommodule" style to change the header on the bottom modules to H6. The third
 * function uses the "sidebar" style to change the header on the sidebar to H3. 
 */

function modChrome_tripletmodule($module, &$params, &$attribs)
{
	$words = explode(" ", $module->title);
	$first_word = $words[0];
	unset($words[0]);
	
	$content = $module->content;
	if (!empty ($content)) : ?>
		<div class="tripletmodule <?php echo htmlspecialchars($params->get('moduleclass_sfx'));?>">
			<?php if ($module->showtitle) : ?>
				<h3><span><?php echo $first_word; ?></span><?php echo ' '.implode(" ", $words); ?></h3>
			<?php endif; ?>
			<?php echo $content; ?>
		</div>
	<?php endif;
}

function modChrome_sidebarcontent($module, &$params, &$attribs)
{	
	$words = explode(" ", $module->title);
	$first_word = $words[0];
	unset($words[0]);
	
	$content = trim($module->content);
	if (!empty ($content)) : ?>
		<div class="sidebarcontent <?php echo htmlspecialchars($params->get('moduleclass_sfx'));?>">
			<?php if ($module->showtitle) : ?>
				<h3><span><?php echo $first_word; ?></span><?php echo ' '.implode(" ", $words); ?></h3>
			<?php endif; ?>
			<?php echo $content; ?>
		</div>
	<?php endif;
}

function modChrome_contentmodule($module, &$params, &$attribs)
{	
	$words = explode(" ", $module->title);
	$first_word = $words[0];
	unset($words[0]);
	
	$content = trim($module->content);
	if (!empty ($content)) : ?>
		<div class="contentmodule <?php echo htmlspecialchars($params->get('moduleclass_sfx'));?>">
			<?php if ($module->showtitle) : ?>
				<h3><span><?php echo $first_word; ?></span><?php echo ' '.implode(" ", $words); ?></h3>
			<?php endif; ?>
			<?php echo $content; ?>
		</div>
	<?php endif;
}

function modChrome_quadrupletmodule($module, &$params, &$attribs)
{
	$words = explode(" ", $module->title);
	$first_word = $words[0];
	unset($words[0]);
	
	$content = $module->content;
	if (!empty ($content)) : ?>
		<div class="quadrupletmodule <?php echo htmlspecialchars($params->get('moduleclass_sfx'));?>">
			<?php if ($module->showtitle) : ?>
				<h3><span><?php echo $first_word; ?></span><?php echo ' '.implode(" ", $words); ?></h3>
			<?php endif; ?>
			<?php echo $content; ?>
		</div>
	<?php endif;
}
?>